/*en    Laurent Constantin's network library (lcrzo)
                 lcrzo_debugdefs
*/
/*fr    Bibliotheque reseau de Laurent Constantin (lcrzo)
                 lcrzo_debugdefs
*/

/*Note : Laurent should be the only person setting those values. */

/*-------------------------------------------------------------*/
#define LCRZO_DEBUG_WAIT_WAIT               0
#define LCRZO_DEBUG_SOCK_TCPSTATE           0
#define LCRZO_DEBUG_UNIX_SIGNALHANDLER      0
#define LCRZO_DEBUG_DEVICE_UNICODE          0
#define LCRZO_DEBUG_LIST_GOTO               0
#define LCRZO_DEBUG_LIST_MEMLEAK            0

#define LCRZO_DEBUG_ERROR_BT                0
#define LCRZO_DEBUG_UNSUPPORTED_ALLOWCOMPIL 0
#define LCRZO_DEBUG_CONF_FAKE               0
#define LCRZO_DEBUG_DATALINK_MODIFYHEADER   0

#define LCRZO_DEBUG_ERROR_OK                0
#define LCRZO_DEBUG_ERROR_PID               0
#define LCRZO_DEBUG_TYPE_NOTSET             0
#define LCRZO_DEBUG_OBSOLETE_REJECT         0
#define LCRZO_DEBUG_MEM_LEAK                0
#define LCRZO_DEBUG_MEM_CORRUPT             0
#define LCRZO_DEBUG_DATASTRINGLIST_MIX      0
#define LCRZO_DEBUG_RES_FDOPEN              0
#define LCRZO_DEBUG_PROCESSOTHEREXIT_WARN   0
#define LCRZO_DEBUG_LIST_CHECK              0


/*-------------------------------------------------------------*/
/*
  LCRZO_DEBUG_WAIT_WAIT :
    Debug functions in lcrzo_wait
    0 : no debug
    1 : debug

  LCRZO_DEBUG_SOCK_TCPSTATE
    Debug virtual TCP client/server of lcrzo_sock.
    0 : no debug
    1 : debug

  LCRZO_DEBUG_UNIX_SIGNALHANDLER
    Debug Unix child processes creation and killing.
    0 : no debug
    1 : debug

  LCRZO_DEBUG_DEVICE_UNICODE
    Debug Unicode device names for Windows.
    0 : no debug
    1 : debug

  LCRZO_DEBUG_ERROR_BT
    Display backtrace of function where the error was first printed.
    0 : no display
    1 : display

  LCRZO_DEBUG_UNSUPPORTED_ALLOWCOMPIL
    Allow compilation to test Unsupported_0_xxx.
    0 : do not allow (LCRZO_DEBUG_UNSUPPORTED_TAKEDECISION in use)
    1 : allow

  LCRZO_DEBUG_ERROR_OK
    Kill the process when return is LCRZO_ERR_OK, .
    0 : do not allow (LCRZO_DEBUG_UNSUPPORTED_TAKEDECISION in use)
    1 : allow

  LCRZO_DEBUG_TYPE_NOTSET
    Using functions lcrzo_priv_notset_xxx, user can mark variables
    as not set.
    0 : do not mark
    1 : mark

  LCRZO_DEBUG_OBSOLETE_REJECT
    Decide if obsolete code and functions should be rejected.
    0 : do not reject
    1 : reject

  LCRZO_DEBUG_MEM_LEAK
    To detect memory leaks.
    0 : no debug
    1 : display allocated and freed data
    2 : create a chained list and display it at the end

  LCRZO_DEBUG_MEM_CORRUPT
    To detect memory corruption.
    0 : no debug
    1 : uninitialized data :
         - read : read data contain a fake uninit_pattern
         - write : no check, this is logical
        bottom data (before allocated data zone) :
         - read : no debug
         - write : check outer_pattern modifications
        top data (after allocated data zone) :
         - read : no debug
         - write : check outer_pattern modifications
        free :
         - read : read data contain a fake free_pattern
         - write : check free_pattern modifications
    2 : uninitialized data :
         - read : read data contain a fake uninit_pattern
         - write : no check, this is logical
        bottom data (before allocated data zone) :
         - read : no debug
         - write : check outer_pattern modifications
        top data (after allocated data zone) :
         - read : protected memory
         - write : protected memory
        free :
         - read : protected memory
         - write : protected memory
    3 : uninitialized data :
         - read : read data contain a fake uninit_pattern
         - write : no check, this is logical
        bottom data (before allocated data zone) :
         - read : protected memory
         - write : protected memory
        top data (after allocated data zone) :
         - read : no debug
         - write : check outer_pattern modifications
        free :
         - read : protected memory
         - write : protected memory

  LCRZO_DEBUG_DATASTRINGLIST_MIX
    To detect mix of usage of lcrzo_datalist and lcrzo_stringlist.
    0 : no detect
    1 : detect

  LCRZO_DEBUG_RES_FDOPEN
    To detect open file descriptors at the end of process.
    0 : no detect
    1 : detect

  LCRZO_DEBUG_PROCESSOTHEREXIT_WARN
    To display a warning if user uses lcrzo_process_other_exit.
    Indeed, this function might be dangerous under Windows, 
    because it might not leave time to close ressources.
    0 : allow usage of lcrzo_process_other_exit
    1 : warn for usage of lcrzo_process_other_exit

*/

/*-------------------------------------------------------------*/
/* special define for lcrzoex compilation */
#if defined NO_LCRZO_DEBUG_ERROR_OK
 #undef LCRZO_DEBUG_ERROR_OK
 #define LCRZO_DEBUG_ERROR_OK 0
#endif

/*-------------------------------------------------------------*/
#if LCRZO_DEBUG_ERROR_OK==1
 #define LCRZO_DEBUG_ERROR_OK_CHECK1(i) lcrzo_debug_err_ok_check(i,LCRZO_FALSE)
 #define LCRZO_DEBUG_ERROR_OK_CHECK2(i) lcrzo_debug_err_ok_check(i,LCRZO_TRUE)
#else
 #define LCRZO_DEBUG_ERROR_OK_CHECK1(a) {}
 #define LCRZO_DEBUG_ERROR_OK_CHECK2(a) {}
#endif

/*-------------------------------------------------------------*/
#if LCRZO_DEBUG_UNSUPPORTED_ALLOWCOMPIL==0
 #define LCRZO_DEBUG_UNSUPPORTED_TAKEDECISION takeadecision+takeadecision;
#else
 #define LCRZO_DEBUG_UNSUPPORTED_TAKEDECISION
#endif
